Index: src/core/SkMatrixImageFilter.h |
diff --git a/src/core/SkMatrixImageFilter.h b/src/core/SkMatrixImageFilter.h |
index 83f2cfaf338b0e2882dea72c6827b5314e09fc6c..86734b629cfdc0ad95073d3bfad992080a23b055 100644 |
--- a/src/core/SkMatrixImageFilter.h |
+++ b/src/core/SkMatrixImageFilter.h |
@@ -24,13 +24,13 @@ public: |
/** Construct a 2D transformation image filter. |
* @param transform The matrix to apply when drawing the src bitmap |
* @param filterLevel The quality of filtering to apply when scaling. |
* @param input The input image filter. If NULL, the src bitmap |
* passed to filterImage() is used instead. |
*/ |
static SkMatrixImageFilter* Create(const SkMatrix& transform, |
SkFilterQuality, |
- SkImageFilter* input = NULL); |
+ SkImageFilter* input = nullptr); |
virtual ~SkMatrixImageFilter(); |
void computeFastBounds(const SkRect&, SkRect*) const override; |
@@ -24,13 +24,13 @@ public: |
* @param transform The matrix to apply when drawing the src bitmap |
* @param filterLevel The quality of filtering to apply when scaling. |
- * @param input The input image filter. If NULL, the src bitmap |
+ * @param input The input image filter. If nullptr, the src bitmap |
* passed to filterImage() is used instead. |
*/ |